@@ -116,9 +116,11 @@ class LetsEncrypt:
         subdomain = tldextract.extract(
             self.hostname).subdomain
         subprocess.call(
-            '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')), shell=True)
-        subprocess.call('{directory}/acme.sh/acme.sh --set-default-ca --server letsencrypt --preferred-chain "ISRG" --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
-            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
+            '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')))
+        subprocess.call(
+            '{directory}/acme.sh/acme.sh --set-default-chain  --preferred-chain isrg  --server letsencrypt')
+        subprocess.call('{directory}/acme.sh/acme.sh --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
+            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'))
 
     def acme_local(self, csr: str) -> None:  # pragma: no cover
         subdomain = tldextract.extract(
@@ -128,6 +130,16 @@ class LetsEncrypt:
         subprocess.call('{directory}/.acme.sh/acme.sh --set-default-ca --test --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --preferred-chain "Fake LE Root X2" --force'.format(
             directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
 
+    def acme_test(self, csr: str) -> None:  # pragma: no cover
+        subdomain = tldextract.extract(
+            self.hostname).subdomain
+        subprocess.call(
+            '{directory}/.acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')), shell=True)
+        subprocess.call(
+            '{directory}/.acme.sh/acme.sh --set-default-chain  --preferred-chain isrg  --server letsencrypt', shell=True)
+        subprocess.call('{directory}/acme.sh/acme.sh --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
+            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
+
     def acme_private_ca_local(self, csr: str, acme_server_url: str) -> None:  # pragma: no cover
         prefix = os.environ['PREFIX']
         root_certificate = get_secret(
